Struct egui_graphs::GraphView

source ·
pub struct GraphView<'a, N: Clone, E: Clone, Ty: EdgeType> { /* private fields */ }
Widget for visualizing and interacting with graphs.

It implements egui::Widget and can be used like any other widget.

The widget uses a mutable reference to the [StableGraph<egui_graphs::Node, egui_graphs::Edge>] struct to visualize and interact with the graph. N and E is arbitrary client data associated with nodes and edges. You can customize the visualization and interaction behavior using SettingsInteraction, SettingsNavigation and SettingsStyle structs.

When any interaction or node property change occurs, the widget sends Change struct to the provided [Sender] channel, which can be set via the with_interactions method. The Change struct contains information about a change that occurred in the graph. Client can use this information to modify external state of his application if needed.

When the user performs navigation actions (zoom & pan, fit to screen), they do not produce changes. This is because these actions are performed on the global coordinates and do not change any properties of the nodes or edges.

Implementations

source

impl<'a, N: Clone, E: Clone, Ty: EdgeType> GraphView<'a, N, E, Ty>

source

pub fn new(g: &'a mut Graph<N, E, Ty>) -> Self

Creates a new GraphView widget with default navigation and interactions settings. To customize navigation and interactions use with_interactions and with_navigations methods.

source

pub fn with_interactions( self, settings_interaction: &SettingsInteraction ) -> Self

Makes widget interactive according to the provided settings.

source

pub fn with_changes(self, changes_sender: &'a Sender<Change>) -> Self

Make every interaction send Change to the provided [crossbeam::channel::Sender] as soon as interaction happens.

Change events can be used to handle interactions on the application side.

source

pub fn with_navigations(self, settings_navigation: &SettingsNavigation) -> Self

Modifies default behaviour of navigation settings.

source

pub fn with_styles(self, settings_style: &SettingsStyle) -> Self

Modifies default style settings.

source

pub fn reset_metadata(ui: &mut Ui)

Resets navigation metadata