pub struct SettingsStyle { /* private fields */ }
SettingsStyle stores settings for the style of the graph.

Implementations

source

impl SettingsStyle

source

pub fn new() -> Self

Creates new SettingsStyle with default values.

use egui_graphs::SettingsStyle;
let settings = SettingsStyle::new();
source

pub fn with_labels_always(self, always: bool) -> Self

Whether to show labels always or when interacted.

Default is false.

source

pub fn with_folded_radius_weight(self, weight: f32) -> Self

For every node folded the folding root node radius is getting bigger by this value.

Default: 2.

source

pub fn with_edge_radius_weight(self, weight: f32) -> Self

For every edge connected to node its radius is getting bigger by this value.

Default: 1.

source

pub fn with_node_color(self, color: Color32) -> Self

Sets default color for node.

source

pub fn with_edge_color(self, color: Color32) -> Self

Sets default color for edge.

source

pub fn color_node_stroke(&self, ctx: &Context) -> Color32