Struct egui_graphs::Graph
source · pub struct Graph<N: Clone, E: Clone, Ty: EdgeType> {
pub g: StableGraph<Node<N>, Edge<E>, Ty>,
}Expand description
Graph type compatible with super::GraphView.
Fields
g: StableGraph<Node<N>, Edge<E>, Ty>Implementations
sourceimpl<'a, N: Clone, E: Clone, Ty: EdgeType> Graph<N, E, Ty>
impl<'a, N: Clone, E: Clone, Ty: EdgeType> Graph<N, E, Ty>
pub fn new(g: StableGraph<Node<N>, Edge<E>, Ty>) -> Self
sourcepub fn walk(
&self,
walker: impl FnMut(&Self, Option<&NodeIndex>, Option<&Node<N>>, Option<&EdgeIndex>, Option<&Edge<E>>)
)
pub fn walk( &self, walker: impl FnMut(&Self, Option<&NodeIndex>, Option<&Node<N>>, Option<&EdgeIndex>, Option<&Edge<E>>) )
Iterates over all nodes and edges and calls the walker function.
sourcepub fn node_by_pos(
&self,
comp: &'a StateComputed,
meta: &'a Metadata,
pos: Pos2
) -> Option<(NodeIndex, &Node<N>)>
pub fn node_by_pos( &self, comp: &'a StateComputed, meta: &'a Metadata, pos: Pos2 ) -> Option<(NodeIndex, &Node<N>)>
Finds node by position. Can be optimized by using a spatial index like quad-tree if needed.
pub fn g(&mut self) -> &mut StableGraph<Node<N>, Edge<E>, Ty>
sourcepub fn nodes_iter(&'a self) -> impl Iterator<Item = (NodeIndex, &Node<N>)>
pub fn nodes_iter(&'a self) -> impl Iterator<Item = (NodeIndex, &Node<N>)>
Provides iterator over all nodes and their indices.
sourcepub fn edges_iter(&'a self) -> impl Iterator<Item = (EdgeIndex, &Edge<E>)>
pub fn edges_iter(&'a self) -> impl Iterator<Item = (EdgeIndex, &Edge<E>)>
Provides iterator over all edges and their indices.
pub fn node(&self, i: NodeIndex) -> Option<&Node<N>>
pub fn edge(&self, i: EdgeIndex) -> Option<&Edge<E>>
pub fn edge_endpoints(&self, i: EdgeIndex) -> Option<(NodeIndex, NodeIndex)>
pub fn node_mut(&mut self, i: NodeIndex) -> Option<&mut Node<N>>
pub fn is_directed(&self) -> bool
pub fn edges_num(&self, idx: NodeIndex) -> usize
pub fn edges_directed( &self, idx: NodeIndex, dir: Direction ) -> impl Iterator<Item = EdgeReference<'_, Edge<E>>>